# -*- coding: utf-8 -*-
from authentic2.settings import INSTALLED_APPS, CACHES
import os

PLATFORM = os.environ.get('PLATFORM')
if PLATFORM not in ['dev', 'test', 'prod']:
    PLATFORM = 'dev'

CORE_ATTRIBUTES = [
    'title',
    'first_name',
    'last_name',
    'birthdate',
    'birthplace',
    'birthcountry'
]

CROWN_ATTRIBUTES = [
    'preferred_username',
    'preferred_givenname',
    'address_number',
    'address_street',
    'address_complement',
    'address_zipcode',
    'address_city',
    'address_country',
    'home_mobile_phone',
    'home_phone',
    'professional_mobile_phone',
    'professional_phone',
    'birthdepartment'
]

# Manager
A2_MANAGER_SHOW_INTERNAL_ROLES = True
A2_MANAGER_ROLE_MEMBERS_FROM_OU = True
A2_MANAGER_USER_SEARCH_MINIMUM_CHARS = 2
A2_MANAGER_ROLES_SHOW_PERMISSIONS = True
A2_MANAGER_ROLE_MEMBERS_FROM_OU = True


A2_REQUIRED_FIELDS = ['email', 'first_name', 'last_name']
A2_PRE_REGISTRATION_FIELDS = ['first_name', 'last_name']

A2_RBAC_MANAGED_CONTENT_TYPES = ()
A2_CUT_PARTNERS = [
    {
        'domains': ['.lyon.fr'],
        'name': u'Ville de Lyon',
    },
    {
        'domains': ['.entrouvert.org'],
        'name': u'Ville de Lyon',
    }
]

if ('Memcached' in CACHES['default']['BACKEND'] or 'Memcached' in
        CACHES['default'].get('REAL_BACKEND', '')):
    try:
        import cachalot
        INSTALLED_APPS += ('cachalot',)
        from cachalot import settings
        settings.SUPPORTED_DATABASE_ENGINES.add('tenant_schemas.postgresql_backend')
        settings.SUPPORTED_CACHE_BACKENDS.add('hobo.multitenant.cache.TenantCache')
    except ImportError as e:
        print 'canot load django-cachalot', e

SESSION_ENGINE = 'django.contrib.sessions.backends.cache'

# 48h pour les mails de reset de mot de passe
PASSWORD_RESET_TIMEOUT_DAYS = 2
A2_EMAIL_CHANGE_TOKEN_LIFETIME = 3600 * 24 * 2
ACCOUNT_ACTIVATION_DAYS = 2


# CACHALOT_UNCACHABLE_TABLES = ('custom_user_user', 'django_migrations')

# OIDC
A2_IDP_OIDC_SCOPES = ['openid', 'email', 'profile', 'crown']

A2_FC_USER_INFO_MAPPINGS = {
    'first_name': 'given_name',
    'last_name': 'family_name',
    'birthdate': {'ref': 'birthdate', 'translation': 'isodate'},
    'birthplace': {'ref': 'birthplace', 'translation': 'insee-communes'},
    'birthcountry': {'ref': 'birthcountry', 'translation': 'insee-countries'},
    'birthplace_insee': 'birthplace',
    'birthcountry_insee': 'birthcountry',
    'preferred_username': 'preferred_username',
    'title': {
        'ref': 'gender',
        'translation': 'simple',
        'translation_simple': {
            'male': 'Monsieur',
            'female': 'Madame',
        }
    },
    'validated': {'value': True},
    'validation_date': {'compute': 'today'},
    'validation_context': {'value': 'FC'},
    'address': 'address.formatted',
    'phone': 'phone',
    'email': {
        'ref': 'email',
        'if-empty': True,
        'tag': 'email',
    },
    'email_verified': {
        'ref': 'email',
        'translation': 'notempty',
        'if-tag': 'email',
    },
}

A2_FC_SCOPES = ['openid', 'identite_pivot', 'email', 'address', 'phone']

TEMPLATE_VARS = {
    "email_signature": u"Le GrandLyon",
    "no_extra_js": True,
    "global_title": u"Compte Unique de Territoire",
    "css_variant": u"grandlyon-cut",
    "theme_color": u"#FF0303",
    "theme": u"grandlyon-cut",
    "default_from_email": u"ne-pas-repondre@grandlyon.com",
    "help_url": u"http://doc-publik.entrouvert.com",
    'theme_base': 'theme.html',
    'theme_base_filename': 'theme.html',
    "account_label": "Compte Unique du Territoire",
}
if PLATFORM == 'dev':
    TEMPLATE_VARS.update({
        "environment_label": u"Site de développement",
        "help_url": "https://portail-citoyen-sau.guichet-recette.grandlyon.com/faq/",
        "partners_url": "https://portail-citoyen-sau.guichet-recette.grandlyon.com/faq/",
    })
elif PLATFORM == 'test':
    TEMPLATE_VARS.update({
        "environment_label": u"Site de test",
        "smarttag_js": "https://tag.aticdn.net/586793/smarttag.js",
        "visits_tracking_js": "var tag = new ATInternet.Tracker.Tag();",
        "help_url": "https://portail-citoyen-sau.guichet-recette.grandlyon.com/faq/",
        "partners_url": "https://portail-citoyen-sau.guichet-recette.grandlyon.com/faq/",
    })
elif PLATFORM == 'prod':
    TEMPLATE_VARS.update({
        "smarttag_js": "https://tag.aticdn.net/586794/smarttag.js",
        "visits_tracking_js": "var tag = new ATInternet.Tracker.Tag();",
        "help_url": "https://portail-citoyen-sau.guichet-recette.grandlyon.com/faq/",
        "partners_url": "https://portail-citoyen-sau.guichet-recette.grandlyon.com/faq/",
    })

A2_HOMEPAGE_URL = '/accounts/'
